pyxmpp.jabber.muccore.MucX

Package pyxmpp :: Package jabber :: Module muccore :: Class MucX |
[hide private]

# Class MucX

source code

                            object --+
                                     |
    objects.StanzaPayloadWrapperObject --+
                                         |
                                  MucXBase --+
                                             |
                                            MucX

Wrapper for http://www.jabber.org/protocol/muc namespaced stanza payload "x" elements.

Instance Methods | [hide private]
__init__(self, xmlnode=None, copy=True, parent=None) Copy MucXBase object or create a new one, possibly based on or wrapping an XML node. | source code
set_history(self, parameters) Set history parameters. | source code
HistoryParameters |
get_history(self) Return history parameters carried by the stanza. | source code
set_password(self, password) Set password for the MUC request. | source code
`unicode` |
get_password(self) Get password from the MUC request. | source code
Inherited from `MucXBase`: `__del__`, `free`, `free_borrowed`, `serialize`, `xpath_eval` Inherited from `objects.StanzaPayloadWrapperObject`: `as_xml` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| ns = ``'``http://jabber.org/protocol/muc``'`` hash(x)
Inherited from `MucXBase`: `element`

Instance Variables | [hide private]
Inherited from `MucXBase`: `xmlnode`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, xmlnode=None, copy=True, parent=None) (Constructor) | source code
Copy MucXBase object or create a new one, possibly based on or wrapping an XML node. Parameters: `xmlnode` - is the object to copy or an XML node to wrap. `copy` - when `True` a copy of the XML node provided will be included in `self`, the node will be copied otherwise. `parent` - parent node for the created/copied XML element. Overrides: object.__init__ (inherited documentation)

### set_history(self, parameters) | source code
Set history parameters. Types: `parameters`: HistoryParameters

### set_password(self, password) | source code
Set password for the MUC request. Parameters: `password` (`unicode`) - password